# This file was auto-generated by Fern from our API Definition.

import typing

AlertTriggerConfigPublicType = typing.Union[
    typing.Literal["scope:project", "threshold:feedback_score", "threshold:cost", "threshold:latency"], typing.Any
]
